<script setup>
import FlexBox from "@/components/FlexBox.vue";
import ChartBox from "@/components/chartBox.vue";
import HdwChart from "@/components/echarts/hdwChart.vue";
import getNormalLine from "@/components/echarts/options/normalLine"
import {onMounted, ref} from "vue";
import getRadiusBarOption from "@/components/echarts/options/radiusBar";

const carName = ref("");
const timeRange = ref("");
timeRange.value = [new Date("2020-01-01 00:00:00"), new Date("2023-01-01 00:00:00")];
const tempBar = ref(null);
const volBar = ref(null);
const alarmLine = ref(null);
const totalVolLine = ref(null);

const resize = ()=>{
  tempBar.value.resize();
  volBar.value.resize();
  alarmLine.value.resize();
  totalVolLine.value.resize();
}

import carInfoModule from "@/views/moudle/battShow/carInfo";
const {carList, getCarNames} = carInfoModule();

import battHistoryModule from "@/views/moudle/battShow/battHistory";
import getDataIndex from "@/util/getDataIndex";

const {
	getBattHistory
} = battHistoryModule();

let totalData = [];
const searchBattHistory = async ()=> {
	slideVal.value = 100;
	try {
		const rs = await getBattHistory(carName.value, timeRange.value);
		let data = [];
		if (rs.code !== 0) {
			data = rs.data;
		}
		totalData = data;

		let currentDataIndex = getDataIndex(totalData.length, slideVal.value);
		console.log(totalData[currentDataIndex]);
	}catch (e) {
		console.log(e);
	}
}

const slideVal = ref(100);

const handleSlideInput = ()=>{
	let currentDataIndex = getDataIndex(totalData.length, slideVal.value);
	if(currentDataIndex !== -1) {
		console.log(totalData[currentDataIndex]);
	}
}

const formatTooltip = (val)=>{
	let currentDataIndex = getDataIndex(totalData.length, slideVal.value);
	let rs = val+"";
	if(currentDataIndex !== -1) {
		let data = totalData[currentDataIndex];
		return new Date(data.gatherTime).format("yyyy-MM-dd hh:mm:ss");
	}
	return rs;
}

onMounted(()=>{

	getCarNames();

  const tempBarOption = getRadiusBarOption({
	  grid: {
		  top: '15%',
		  right: '3%',
		  left: '5%',
		  bottom: '5%'
	  }
  });
  tempBar.value.setOption(tempBarOption);

  const volBarOption = getRadiusBarOption({
	  grid: {
		  top: '15%',
		  right: '3%',
		  left: '5%',
		  bottom: '5%'
	  }
  });
  volBar.value.setOption(volBarOption);

  const alarmLineOption = getNormalLine();
  alarmLine.value.setOption(alarmLineOption);

  const totalVolLineOption = getNormalLine();
  totalVolLine.value.setOption(totalVolLineOption);

	resize();
});
</script>

<template>
  <div class="batt-show-wrapper">
    <div class="batt-show-layout">
      <div class="batt-show-header">
        <div class="input-list">
          <div class="input-item">
            <div class="input-wrapper">
              <div class="input-label">车辆名称:</div>
              <div class="input-content">
                <el-select v-model="carName" filterable>
                  <el-option
	                  v-for="(item, key) in carList" :key="'key'+key"
                    :value="item.key" :label="item.label"></el-option>
                </el-select>
              </div>
            </div>
          </div>
          <div class="input-item">
            <div class="input-wrapper">
              <div class="input-label">日期选择:</div>
              <div class="input-content">
                <el-date-picker
                    v-model="timeRange"
                    type="datetimerange"
                    start-placeholder="开始时间"
                    end-placeholder="结束时间"
                    format="YYYY-MM-DD HH:mm:ss"
                    date-format="YYYY/MM/DD ddd"
                    time-format="A hh:mm:ss"></el-date-picker>
              </div>
            </div>
          </div>
	        <div class="input-item">
		        <el-button type="primary" @click="searchBattHistory">查询</el-button>
	        </div>
        </div>
      </div>
      <div class="batt-show-body">
	      <div class="batt-chart-list-wrapper">
		      <div class="batt-chart-list-content">
			      <div class="batt-chart-list top">
				      <div class="batt-chart-item left">
					      <flex-box>
						      <div class="flex-box-content">
							      <chart-box title="单体温度">
								      <hdw-chart ref="tempBar"></hdw-chart>
							      </chart-box>
						      </div>
					      </flex-box>
				      </div>
				      <div class="batt-chart-item right">
					      <flex-box>
						      <div class="flex-box-content">
							      <chart-box title="单体电压">
								      <hdw-chart ref="volBar"></hdw-chart>
							      </chart-box>
						      </div>
					      </flex-box>
				      </div>
			      </div>
			      <div class="batt-chart-list bottom">
				      <div class="batt-chart-item left">
					      <flex-box>
						      <div class="flex-box-content">
							      <chart-box title="告警事件">
								      <hdw-chart ref="alarmLine"></hdw-chart>
							      </chart-box>
						      </div>
					      </flex-box>
				      </div>
				      <div class="batt-chart-item right">
					      <flex-box>
						      <div class="flex-box-content">
							      <chart-box title="总单体电压">
								      <hdw-chart ref="totalVolLine"></hdw-chart>
							      </chart-box>
						      </div>
					      </flex-box>
				      </div>
			      </div>
		      </div>
		      <div class="batt-chart-list-footer">
			      <el-slider
				      v-model="slideVal"
				      :format-tooltip="formatTooltip"
				      :format-value-text="formatTooltip"
				      @input="handleSlideInput"></el-slider>
		      </div>
	      </div>

      </div>
    </div>
  </div>
</template>

<style scoped lang="less">
.batt-show-wrapper {
  height: 100%;
  background: url("@/assets/images/dw_bg.jpg") no-repeat;
  background-size: 100% 100%;
  .batt-show-layout {
    display: flex;
    flex-direction: column;
    height: 100%;
    .batt-show-header {
      padding: 8px 8px 4px 8px;
    }
    .batt-show-body {
      flex: 1;
      padding: 4px 8px 8px 8px;
    }
  }
}
.batt-chart-list-wrapper {
	display: flex;
	height: 100%;
	flex-direction: column;
	.batt-chart-list-content {
		flex: 1;
		.batt-chart-list {
			display: flex;
			height: 50%;
			&.top {
				padding-bottom: 4px;
			}
			&.bottom {
				padding-top: 4px;
			}
			.batt-chart-item {
				flex:1;
				&.left {
					padding-right: 4px;
				}
				&.right {
					padding-left: 4px;
				}
			}
		}
	}
	.batt-chart-list-footer {
		padding: 4px 16px;
	}
}
.flex-box-content {
  height: 100%;
  padding: 8px 0 8px 8px;
}
.input-list {
  .input-item {
    display: inline-block;
    margin-left: 8px;
  }
}
.input-wrapper {
  display: flex;
  .input-content {
    min-width: 160px;
    vertical-align: middle;
  }
  .input-label {
    display: inline-block;
    line-height: 32px;
    color: #fff;
    font-size: 14px;
    margin-right: 8px;
    vertical-align: middle;
  }
}
</style>
